==> karot_components-0.0.2.tar.gz: lib/dialog/karot_show_card_info_dialog.dart <==
import 'package:flutter/material.dart';
import 'package:karot_components/constant/dialog_enum.dart';
import '../card/karot_card_dialog.dart';

class KRCardInfoDialog {
  KRCardInfoDialog._();

  static Future<void> showKarotAlertDialog(BuildContext context,
      {
        KRDialog? dialogType,
      required String title,
      required String bodyText,
      VoidCallback? onConfirmTap,
      String? confirmText,
      required VoidCallback onDismissTap}) async {
    return showDialog(
        context: context,
        barrierDismissible: false, // user must tap button!
        builder: (BuildContext context) {
          return AlertDialog(
              shape: const RoundedRectangleBorder(
                  borderRadius: BorderRadius.all(Radius.circular(30.0))),
              content: KRCardDialog(
                onConfirmTap: onConfirmTap,
                assetURL: dialogType?.value,
                title: title,
                bodyText: bodyText,
                confirmText : confirmText,
                onDismissTap: onDismissTap,
              ));
        });
  }

}



// extends StatelessWidget {
//   final KRDialog dialogType;
//   final String title;
//   final String bodyText;
//   final VoidCallback onDismissTap;

//   const KRCardInfoDialog(
//       {Key? key,
//       required this.dialogType,
//       required this.title,
//       required this.bodyText, required this.onDismissTap})
//       : super(key: key);

//   @override
//   Widget build(BuildContext context) {
//     return 
//   }
// }

==> karot_components-0.0.5.tar.gz: lib/dialog/karot_show_card_info_dialog.dart <==
import 'package:flutter/material.dart';
import 'package:karot_components/constant/dialog_enum.dart';
import '../card/karot_card_dialog.dart';

class KRCardInfoDialog {
  KRCardInfoDialog._();

  static Future<void> showKarotAlertDialog(BuildContext context,
      {KRDialog? dialogType,
      required String title,
      required String bodyText,
      required VoidCallback onDismissTap,
      VoidCallback? onConfirmTap,
      String confirmText = "Sure",
      String dismissText = 'Cancel'}) async {
    return showDialog(
        context: context,
        barrierDismissible: false, // user must tap button!
        builder: (BuildContext context) {
          return AlertDialog(
              shape: const RoundedRectangleBorder(
                  borderRadius: BorderRadius.all(Radius.circular(30.0))),
              content: KRCardDialog(
                assetURL: dialogType?.value,
                title: title,
                bodyText: bodyText,
                dismissText: dismissText,
                onDismissTap: onDismissTap,
                onConfirmTap : onConfirmTap,
                confirmText: confirmText,
              ));
        });
  }
}



// extends StatelessWidget {
//   final KRDialog dialogType;
//   final String title;
//   final String bodyText;
//   final VoidCallback onDismissTap;

//   const KRCardInfoDialog(
//       {Key? key,
//       required this.dialogType,
//       required this.title,
//       required this.bodyText, required this.onDismissTap})
//       : super(key: key);

//   @override
//   Widget build(BuildContext context) {
//     return 
//   }
// }
